@@ -65,18 +65,29 @@ function usedAnswers = PsychLinuxConfiguration(answers)
 %                  group 'psychtoolbox' with setgid flag set, and write permissions,
 %                  to allow members of the 'psychtoolbox' user group to add/remove/
 %                  modify xorg.conf files without need for admin permissions.
+% 27.06.2016   mk  Optionally install a /etc/modprobe.d/blacklist-psychtoolbox.conf
+%                  file to prevent loading of certain kernel modules, e.g., the 'lp'
+%                  module for control of parallel port line printers, which would prevent
+%                  exclusive access to parallel ports for digital i/o.
+%                  Also add users to the 'lp' group for parallel port access, and
+%                  on ARM architecture (RaspberryPi) to the 'gpio' group for GPIO
+%                  pin access.
+% 04.09.2016   mk  Optionally install a /etc/modprobe.d/amddeepcolor-psychtoolbox.conf
+%                  file to switch radeon-kms / amdgpu-kms into deep color mode for
+%                  driving suitable HDMI/DP > 8 bpc displays.
 
 rerun = 0;
+updateinitramfs = 0;
 
 if ~IsLinux
   return;
 end
 
 if nargin < 1 || isempty(answers)
-  answers = '????';
+  answers = '??????';
 else
-  if ~ischar(answers) || length(answers) ~= 4
-    error('Provided input argument ''answers'' must be a 4 character string with characters y, n or ?');
+  if ~ischar(answers) || length(answers) ~= 6
+    error('Provided input argument ''answers'' must be a 6 character string with characters y, n or ?');
   end
 end
 
@@ -165,6 +176,117 @@ if needinstall && answer == 'y'
   end
 end
 
+% Check if psychtoolbox modules blacklist file exists:
+fprintf('\n\n');
+if ~exist('/etc/modprobe.d/blacklist-psychtoolbox.conf', 'file')
+  % No: Needs to be installed.
+  needinstall = 1;
+  fprintf('The blacklist file for Psychtoolbox is not installed on your system.\n');
+  if ismember(answers(5), 'yn')
+    answer = answers(5);
+  else
+    answer = input('Should i install it? [y/n] : ', 's');
+    answers(5) = answer;
+  end
+else
+  % Yes.
+  fprintf('The blacklist file for Psychtoolbox is already installed on your system.\n');
+
+  % Compare its modification date with the one in PTB:
+  r = dir([PsychtoolboxRoot '/PsychHardware/blacklist-psychtoolbox.conf']);
+  i = dir('/etc/modprobe.d/blacklist-psychtoolbox.conf');
+
+  if r.datenum > i.datenum
+    needinstall = 2;
+    fprintf('However, it seems to be outdated. I have a more recent version with me.\n');
+    if ismember(answers(5), 'yn')
+      answer = answers(5);
+    else
+      answer = input('Should i update it? [y/n] : ', 's');
+      answers(5) = answer;
+    end
+  end
+end
+
+if needinstall && answer == 'y'
+  if IsOctave && IsGUI
+    rerun = 1;
+    fprintf('Oops, we are running under Octave in GUI mode. This will not work!\n');
+    fprintf('But not to worry. Just run Octave from a terminal window later once without\n');
+    fprintf('GUI, e.g., via executing: octave --no-gui\n');
+    fprintf('Then run the PsychLinuxConfiguration command again to make things work.\n');
+  else
+    fprintf('I will copy my most recent blacklist file to your system. Please enter\n');
+    fprintf('now your system administrator password. You will not see any feedback.\n');
+    drawnow;
+    cmd = sprintf('sudo cp %s/PsychHardware/blacklist-psychtoolbox.conf /etc/modprobe.d/', PsychtoolboxRoot);
+    [rc, msg] = system(cmd);
+    if rc == 0
+      fprintf('Success! You may need to reboot your machine for some changes to take effect.\n');
+    else
+      fprintf('Failed! The error message was: %s\n', msg);
+    end
+  end
+end
+
+% Check if psychtoolbox AMD kms modules config file exists:
+fprintf('\n\n');
+if ~exist('/etc/modprobe.d/amddeepcolor-psychtoolbox.conf', 'file')
+  % No: Needs to be installed.
+  needinstall = 1;
+  fprintf('The amd deep color file for Psychtoolbox is not installed on your system.\n');
+  fprintf('This file needs to be installed if you want to use a graphics card from AMD\n');
+  fprintf('to drive a HDMI or DisplayPort high precision display device with more than\n');
+  fprintf('8 bpc color depths, ie. more than 256 levels of red, green and blue color.\n');
+  fprintf('You do not need to install it for pure 8 bpc mode or with other graphics cards.\n');
+  if ismember(answers(6), 'yn')
+    answer = answers(6);
+  else
+    answer = input('Should i install it? [y/n] : ', 's');
+    answers(6) = answer;
+  end
+else
+  % Yes.
+  fprintf('The amd deep color file for Psychtoolbox is already installed on your system.\n');
+
+  % Compare its modification date with the one in PTB:
+  r = dir([PsychtoolboxRoot '/PsychHardware/amddeepcolor-psychtoolbox.conf']);
+  i = dir('/etc/modprobe.d/amddeepcolor-psychtoolbox.conf');
+
+  if r.datenum > i.datenum
+    needinstall = 2;
+    fprintf('However, it seems to be outdated. I have a more recent version with me.\n');
+    if ismember(answers(6), 'yn')
+      answer = answers(6);
+    else
+      answer = input('Should i update it? [y/n] : ', 's');
+      answers(6) = answer;
+    end
+  end
+end
+
+if needinstall && answer == 'y'
+  if IsOctave && IsGUI
+    rerun = 1;
+    fprintf('Oops, we are running under Octave in GUI mode. This will not work!\n');
+    fprintf('But not to worry. Just run Octave from a terminal window later once without\n');
+    fprintf('GUI, e.g., via executing: octave --no-gui\n');
+    fprintf('Then run the PsychLinuxConfiguration command again to make things work.\n');
+  else
+    fprintf('I will copy my most recent amd deep color file to your system. Please enter\n');
+    fprintf('now your system administrator password. You will not see any feedback.\n');
+    drawnow;
+    cmd = sprintf('sudo cp %s/PsychHardware/amddeepcolor-psychtoolbox.conf /etc/modprobe.d/', PsychtoolboxRoot);
+    [rc, msg] = system(cmd);
+    if rc == 0
+      updateinitramfs = 1;
+      fprintf('Success! You will need to reboot your machine for this change to take effect.\n');
+    else
+      fprintf('Failed! The error message was: %s\n', msg);
+    end
+  end
+end
+
 % First the fallback implementation if /etc/security/limits.d/ does not
 % exist:
 if ~exist('/etc/security/limits.d/', 'dir')
@@ -336,13 +458,21 @@ if addgroup
   fprintf('sudo usermod -a -G psychtoolbox %s\n\n', username);
   fprintf('One should also add oneself to the ''dialout'' group for access to serial port devices:\n\n');
   fprintf('sudo usermod -a -G dialout %s\n\n', username);
+  fprintf('One should also add oneself to the ''lp'' group for access to parallel port devices:\n\n');
+  fprintf('sudo usermod -a -G lp %s\n\n', username);
+  fprintf('One should also add oneself to the ''video'' group for use on hybrid graphics laptops:\n\n');
+  fprintf('sudo usermod -a -G video %s\n\n', username);
+  if IsARM
+    fprintf('One should also add oneself to the ''gpio'' group for access to GPIO pins:\n\n');
+    fprintf('sudo usermod -a -G gpio %s\n\n', username);
+  end
   fprintf('After that, the new group member must log out and then login again for the\n');
   fprintf('settings to take effect.\n\n');
   if ismember(answers(3), 'yn')
     answer = answers(3);
   else
     fprintf('Actually we could do this for you right now.\n');
-    answer = input('Should i add you to the psychtoolbox and dialout user groups? [y/n] : ', 's');
+    answer = input('Should i add you to the user groups proposed above? [y/n] : ', 's');
     answers(3) = answer;
   end
 
@@ -354,6 +484,16 @@ if addgroup
       system(cmd);
       cmd = sprintf('sudo usermod -a -G dialout %s', username);
       system(cmd);
+      cmd = sprintf('sudo usermod -a -G lp %s', username);
+      system(cmd);
+      cmd = sprintf('sudo usermod -a -G video %s', username);
+      system(cmd);
+
+      % On RaspberryPi also add to the gpio group for GPIO access:
+      if IsARM
+        cmd = sprintf('sudo usermod -a -G gpio %s', username);
+        system(cmd);
+      end
 
       % Another one?
       username = input('Enter the name of another user to add, or just press Return to be done: ', 's');
@@ -396,14 +536,20 @@ if addgroup
   end
 end
 
+if updateinitramfs
+  fprintf('\nNow updating the initramfs for some settings to take effect. This can take some time.\n');
+  system('sudo update-initramfs -u -k all');
+end
+
 if ~rerun
   fprintf('\nFinished. Your system should now be ready for use with Psychtoolbox.\n');
   fprintf('If you encounter problems, try rebooting the machine. Some of the settings only\n');
   fprintf('become effective after a reboot.\n\n\n');
 else
   fprintf('\nSetup failed due to lack of administrator permissions. Please run octave\n');
-  fprintf('from a terminal window via octave --no-gui while logged in as an administrator user\n');
-  fprintf('and then execute the command\n\nPsychLinuxConfiguration(''%s'');\n\n', answers);
+  fprintf('from a terminal window via ''octave --no-gui'' while logged in as a user with\n');
+  fprintf('administrator capabilities.\n');
+  fprintf('Then execute the command\n\nPsychLinuxConfiguration(''%s'');\n\n', answers);
   fprintf('to rerun this script again with the same settings, so you can avoid\n');
   fprintf('answering all yes/no questions again. Then it should work.\n\n\n');
 end
