@@ -64,6 +64,11 @@ function PsychtoolboxPostInstallRoutine(isUpdate, flavor)
 % 01/27/2016 Use Octave3 folder for mex files for both Octave-3 and Octave-4. (MK)
 % 03/15/2016 Need liboctave-dev package for symlinks liboctinterp.so -> Octave specific liboctinterp.x.so (MK)
 % 04/01/2016 64-Bit Octave-4 support for MS-Windows established. (MK)
+% 05/13/2016 Add new rpath fixup for Octave on OSX - Copy runtime libs to search dirs. (MK)
+% 06/01/2016 32-Bit Octave-4 support for MS-Windows removed. (MK)
+%            64-Bit Octave-3 support for OSX removed. (MK)
+%            OSX 10.8 and 10.9 support removed. (MK)
+% 07/06/2016 No upstream support for 32-Bit Octave on Linux anymore. NeuroDebian provides it though. (MK)
 
 fprintf('\n\nRunning post-install routine...\n\n');
 
@@ -151,13 +156,25 @@ catch
 end
 
 % 32-Bit Octave or 32-Bit Matlab on OSX? This is unsupported as of Version 3.0.11.
-if IsOSX && ~Is64Bit
-    fprintf('Psychtoolbox 3.0.11 and later do no longer work with 32-Bit versions of Octave or Matlab on OSX.\n');
-    fprintf('You need to upgrade to a 64-Bit version of Octave or Matlab on OSX, which is fully supported.\n');
+if (IsOSX || IsWin) && ~Is64Bit
+    fprintf('Psychtoolbox 3.0.13 and later versions do no longer work with 32-Bit versions of Octave or Matlab on OSX or Windows.\n');
+    fprintf('You need to upgrade to a 64-Bit version of Octave or Matlab on these systems, which is fully supported.\n');
     fprintf('You can also use the alternate download function DownloadLegacyPsychtoolbox() to download\n');
     fprintf('an old legacy copy of Psychtoolbox-3.0.9, which did support 32-Bit Octave 3.2 on OSX, or use\n');
     fprintf('DownloadPsychtoolbox() with flavor ''Psychtoolbox-3.0.10'', which does support 32-Bit Matlab on OSX.\n');
-    error('Tried to setup on 32-Bit Octave, which is no longer supported on OSX.');
+    fprintf('DownloadPsychtoolbox() with flavor ''Psychtoolbox-3.0.12'', does support 32-Bit Octave-4 on Windows.\n');
+    error('Tried to setup on 32-Bit Octave, which is no longer supported on OSX or Windows.');
+end
+
+if IsLinux && ~Is64Bit && IsOctave && ~IsARM
+    fprintf('Psychtoolbox 3.0.13 no longer provides up to date mex files for 32-Bit Octave on Linux.\n');
+    fprintf('The only exception is 32-Bit Octave for Linux on ARM processors like the RaspberryPi.\n');
+    fprintf('Not to worry though, you can get a fully supported Psychtoolbox 3.0.13 for 32-Bit Octave\n');
+    fprintf('on Linux from the NeuroDebian project if you run Debian GNU/Linux or a Ubuntu flavor.\n');
+    fprintf('Go to this link for installation instructions:\n');
+    fprintf('http://neuro.debian.net/pkgs/octave-psychtoolbox-3.html#pkg-octave-psychtoolbox-3\n\n');
+    fprintf('\n\nPress any key to continue after you have read and understood above message.\n\n');
+    pause;
 end
 
 if ~Is64Bit && ~IsOctave
@@ -229,19 +246,19 @@ if IsOSX
         minorver = inf;
     end
 
-    % Is the operating system version < 10.8?
-    if minorver < 8
-        % Yes. This is MacOSX 10.7 or earlier, i.e., older than 10.8
-        % Mountain Lion. PTB will not work on such an old system:
+    % Is the operating system version < 10.10?
+    if minorver < 10
+        % Yes. This is MacOSX 10.9 or earlier, i.e., older than 10.10
+        % Yosemite. PTB will not work on such an old system:
         fprintf('\n\n\n\n\n\n\n\n==== WARNING WARNING WARNING WARNING ====\n\n');
         fprintf('Your operating system is Mac OS/X version 10.%i.\n\n', minorver);
         fprintf('This release of Psychtoolbox-3 is not compatible\n');
-        fprintf('to OSX versions older than 10.8 "Mountain Lion".\n');
+        fprintf('to OSX versions older than 10.10 "Yosemite".\n');
         fprintf('That means that almost all functionality will not work!\n\n');
         fprintf('You could download an older version of Psychtoolbox\n');
         fprintf('onto your system to get better results. See our Wiki for help.\n');
         fprintf('Better though, update your operating system to at least version\n');
-        fprintf('10.8.5 or later, better the very latest OSX version.\n');
+        fprintf('10.11.5 or later, better the very latest OSX version.\n');
         fprintf('\n\n\n==== WARNING WARNING WARNING WARNING ====\n\n\n');
         fprintf('Press any key on keyboard to try to continue with setup, although\n');
         fprintf('this will likely fail soon and leave you with a dysfunctional toolbox.\n\n');
@@ -300,10 +317,22 @@ if IsOctave
             rmpath([PsychtoolboxRoot 'PsychBasic' filesep 'Octave3OSXFiles64']);
         end
 
+        if exist([PsychtoolboxRoot 'PsychBasic' filesep 'Octave4OSXFiles64'], 'dir')
+            rmpath([PsychtoolboxRoot 'PsychBasic' filesep 'Octave4OSXFiles64']);
+        end
+
         if exist([PsychtoolboxRoot 'PsychBasic' filesep 'Octave3WindowsFiles'], 'dir')
             rmpath([PsychtoolboxRoot 'PsychBasic' filesep 'Octave3WindowsFiles']);
         end
 
+        if exist([PsychtoolboxRoot 'PsychBasic' filesep 'Octave4WindowsFiles'], 'dir')
+            rmpath([PsychtoolboxRoot 'PsychBasic' filesep 'Octave4WindowsFiles']);
+        end
+
+        if exist([PsychtoolboxRoot 'PsychBasic' filesep 'Octave4WindowsFiles64'], 'dir')
+            rmpath([PsychtoolboxRoot 'PsychBasic' filesep 'Octave4WindowsFiles64']);
+        end
+
         % Encode prefix and Octave major version of proper folder:
         octavev = sscanf(version, '%i.%i');
         octavemajorv = octavev(1);
@@ -361,17 +390,14 @@ if IsOctave
         fprintf('=====================================================================\n\n');
     end
 
-    if (IsWin && (octavemajorv < 4)) || (octavemajorv < 3) || (octavemajorv == 3 && octaveminorv < 2)
+    if (~IsLinux && (octavemajorv < 4)) || (octavemajorv < 3) || (octavemajorv == 3 && octaveminorv < 2)
         fprintf('\n\n=================================================================================\n');
         fprintf('WARNING: Your version %s of Octave is obsolete. We strongly recommend\n', version);
         if IsLinux
             % On Linux everything >= 3.2 is fine:
             fprintf('WARNING: using the latest stable version of the Octave 3.2.x series or later for use with Psychtoolbox.\n');
-        elseif IsOSX
-            % On OSX we only care about >= 3.8 atm:
-            fprintf('WARNING: using the latest stable version of the Octave 3.8.x series or later for use with Psychtoolbox.\n');
         else
-            % On Windows we only care about >= 4.0 atm:
+            % On Windows/OSX we only care about >= 4.0 atm:
             fprintf('WARNING: using the latest stable version of the Octave 4.0.x series for use with Psychtoolbox.\n');
         end
         fprintf('WARNING: Stuff may not work at all or only suboptimal with other versions and we\n');
@@ -381,6 +407,25 @@ if IsOctave
         pause;
     end
 
+    if IsOSX
+        % Need to copy the Octave runtime libraries somewhere our mex files can find them. The only low-maintenance
+        % way of dealing with this mess of custom library pathes per octave version, revision and packaging format.
+        % Preferred location is the folder with our mex files - found by rpath = @loader_path
+        if ~copyfile([octave_config_info.octlibdir filesep 'liboctinterp.3.dylib'], [rdir filesep], 'f') || ...
+           ~copyfile([octave_config_info.octlibdir filesep 'liboctave.3.dylib'], [rdir filesep], 'f')
+            % Copy into our mex files folder failed. A second location where the linker will search is the
+            % $HOME/lib directory of the current user, so try that as target location:
+            tdir = PsychHomeDir('lib');
+            fprintf('\n\nFailed to copy Octave runtime libraries to mex file folder [%s].\nRetrying in users private lib dir: %s ...\n', rdir, tdir);
+            if ~copyfile([octave_config_info.octlibdir filesep 'liboctinterp.3.dylib'], tdir, 'f') || ...
+               ~copyfile([octave_config_info.octlibdir filesep 'liboctave.3.dylib'], tdir, 'f')
+                fprintf('\nFailed to copy runtime libs to [%s] as well :(.\n', tdir);
+                fprintf('Our mex files will likely not work this way. Maybe the directories lack file write permissions?\n');
+                fprintf('\n\n\nA last workaround would be to restart octave from a terminal via this line:\n\nexport DYLD_LIBRARY_PATH=%s ; octave\n\n\n', octave_config_info.octlibdir);
+            end
+        end
+    end
+
     try
         % Rehash the Octave toolbox cache:
         path(path);
@@ -404,7 +449,7 @@ if IsOctave
             fprintf('ERROR: might by missing, causing our mex files to fail to load with linker errors.\n');
         end
         fprintf('ERROR: One reason might be that your version %s of Octave is incompatible. We recommend\n', version);
-        fprintf('ERROR: use of the latest stable version of Octave-3 or 4 as announced on the www.octave.org website.\n');
+        fprintf('ERROR: use of the latest stable version of Octave-4 as announced on the www.octave.org website.\n');
         fprintf('ERROR: Another conceivable reason would be missing or incompatible required system libraries on your system.\n\n');
         fprintf('ERROR: After fixing the problem, restart this installation/update routine.\n\n');
         fprintf('\n\nInstallation aborted. Fix the reported problem and retry.\n\n');
@@ -542,7 +587,9 @@ try
         fprintf('on Linux. Psychtoolbox''s Screen() command will not work without GStreamer!\n\n');
 
         % Additional setup instructions for embedded/mobile devices with ARM cpu required?
-        if IsARM
+        % No point anymore. Not needed for RaspberryPi, and our Nexus-7
+        % support is essentially dead...
+        if 0 && IsARM
             fprintf('Additionally, as this is a device with ARM processor, the helper library\n');
             fprintf('libwaffle-1.so needs to be installed in a system library folder for Screen\n');
             fprintf('to work. You can find a copy of the library in the PsychContributed/ArmArch/\n');
@@ -658,8 +705,11 @@ fprintf('to support its ongoing maintenance and development. See: \n');
 fprintf('\n');
 fprintf('http://psychtoolbox.org/donations \n');
 fprintf('\n');
-
 fprintf('\nEnjoy!\n\n');
+fprintf('Press RETURN or ENTER to confirm you read and understood the above message.\n');
+pause;
+fprintf('\n\n');
+PTBSurvey;
 
 % Clear out everything:
 if IsWin
