@@ -52,6 +52,7 @@ function SetupPsychtoolbox
 % 05/18/14 mk  No support for 32-Bit Matlab on Linux and Windows anymore for 3.0.12.
 % 10/28/15 mk  32-Bit Octave-4 support for MS-Windows reestablished.
 % 04/01/16 mk  64-Bit Octave-4 support for MS-Windows established.
+% 06/01/16 mk  32-Bit Octave-4 support for MS-Windows removed.
 
 % Flush all MEX files: This is needed at least on M$-Windows to
 % work if Screen et al. are still loaded.
@@ -86,6 +87,14 @@ if strcmp(computer, 'i686-pc-mingw32')
     error('Tried to setup on Octave, which is no longer supported on MS-Windows.');
 end
 
+% Check if this is 32-Bit Octave-4 on Windows, which we don't support at all:
+if isempty(strfind(computer, 'x86_64')) && ~isempty(strfind(computer, 'mingw32'))
+    fprintf('Psychtoolbox 3.0.13 and later do no longer work with 32-Bit GNU/Octave-4 on MS-Windows.\n');
+    fprintf('You need to use 64-Bit Octave-4 if you want to use Psychtoolbox with Octave on Windows.\n');
+    fprintf('DownloadPsychtoolbox() with flavor ''Psychtoolbox-3.0.12'', does support 32-Bit Octave-4 on Windows.\n');
+    error('Tried to setup on 32-Bit Octave, which is no longer supported on Windows.');
+end
+
 if strcmp(computer,'MAC')
     fprintf('This version of Psychtoolbox is no longer supported under MacOSX on the Apple PowerPC hardware platform.\n');
     fprintf('You can get modern versions of Psychtoolbox-3 for Linux if you choose to install GNU/Linux on your PowerPC\n');
